Clazz.declarePackage("JSV.dialog");
(function(){
var c$ = Clazz.declareType(JSV.dialog, "DialogParams", null);
})();
;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
